@@ -35,8 +35,8 @@ class JSONField(models.TextField):
         return super(JSONField, self).formfield(form_class=JSONFormField, **kwargs)
     
     def validate(self, value, model_instance):
-        if not self.null and not value:
-            raise ValidationError(self.error_messages['required'])
+        if not self.null and value is None:
+            raise ValidationError(self.error_messages['null'])
         try:
             self.get_db_prep_value(value)
         except:
